pub struct OpenIdConfig {
pub name: String,
pub image: Url,
pub config_endpoint: Url,
pub upstream_cluster: String,
pub authority: String,
pub redirect_uri: Url,
pub client_id: String,
pub scope: String,
pub claims: Map<String, Value>,
pub client_secret: Secret<String>,
pub audience: String,
}Expand description
Struct that holds the configuration for the OpenID Connect provider
Fields
name: StringName of the OpenID Connect Provider
image: UrlImage of the OpenID Connect Provider, will be shown in the screen where the user can select the provider
config_endpoint: UrlConfig endpoint for the plugin.
upstream_cluster: StringUpstream Cluster name
The authority that will be used for the dispatch calls
redirect_uri: UrlThe redirect uri that the authorization endpoint will redirect to and provide the code
client_id: StringThe client id
scope: StringThe scope
claims: Map<String, Value>The claims
client_secret: Secret<String>The client secret
audience: StringThe audience. Sometimes its the same as the client id