struct V1PluginConfiguration {Show 22 fields
pub config_endpoint: Url,
pub reload_interval_in_h: u64,
pub exclude_hosts: Vec<Regex>,
pub exclude_paths: Vec<Regex>,
pub exclude_urls: Vec<Regex>,
pub access_token_header_name: Option<String>,
pub access_token_header_prefix: Option<String>,
pub id_token_header_name: Option<String>,
pub id_token_header_prefix: Option<String>,
pub cookie_name: String,
pub logout_path: Option<String>,
pub filter_plugin_cookies: bool,
pub cookie_duration: u64,
pub token_validation: bool,
pub aes_key: Secret<Aes256Gcm>,
pub authority: String,
pub redirect_uri: Url,
pub client_id: String,
pub scope: String,
pub claims: String,
pub client_secret: Secret<String>,
pub audience: String,
}Expand description
Legacy configuration structure for backwards compatibility. This represents the old flat configuration format that only supported a single provider.
Fields
config_endpoint: UrlConfig endpoint for the plugin.
reload_interval_in_h: u64Reload interval in hours
exclude_hosts: Vec<Regex>Exclude hosts. Example: localhost:10000
exclude_paths: Vec<Regex>Exclude paths. Example: /health
exclude_urls: Vec<Regex>Exclude urls. Example: localhost:10000/health
access_token_header_name: Option<String>The header name that will be used for the access token.
access_token_header_prefix: Option<String>Prefix for the access token header.
id_token_header_name: Option<String>The header name that will be used for the id token.
id_token_header_prefix: Option<String>Prefix for the id token header.
The cookie name that will be used for the session cookie
logout_path: Option<String>The URL to logout the user (optional in legacy format, defaults to “/logout”)
Filter out the cookies created and controlled by the plugin
The cookie duration in seconds
token_validation: boolOption to skip Token Validation
aes_key: Secret<Aes256Gcm>AES Key
The authority that will be used for the dispatch calls
redirect_uri: UrlThe redirect uri that the authorization endpoint will redirect to and provide the code
client_id: StringThe client id
scope: StringThe scope
claims: StringThe claims (as a JSON string in the legacy format)
client_secret: Secret<String>The client secret
audience: StringThe audience
Implementations
Sourceimpl V1PluginConfiguration
impl V1PluginConfiguration
Sourcefn to_new_format(self) -> Result<V2PluginConfiguration>
fn to_new_format(self) -> Result<V2PluginConfiguration>
Convert legacy configuration to new multi-provider format