V2PluginConfiguration

Struct V2PluginConfiguration 

pub struct V2PluginConfiguration {
Show 16 fields pub exclude_hosts: Vec<Regex>, pub exclude_paths: Vec<Regex>, pub exclude_urls: Vec<Regex>, pub access_token_header_name: Option<String>, pub access_token_header_prefix: Option<String>, pub id_token_header_name: Option<String>, pub id_token_header_prefix: Option<String>, pub cookie_name: String, pub logout_path: String, pub filter_plugin_cookies: bool, pub cookie_duration_in_s: u64, pub token_validation: bool, pub aes_key: Secret<Aes256Gcm>, pub reload_interval_in_h: u64, pub ticking_interval_in_ms: u64, pub open_id_configs: Vec<OpenIdConfig>,
}
Struct that holds the configuration for the plugin. It is loaded from the config file envoy.yaml

Fields

exclude_hosts: Vec<Regex>

Exclude hosts. Example: localhost:10000

exclude_paths: Vec<Regex>

Exclude paths. Example: /health

exclude_urls: Vec<Regex>

Exclude urls. Example: localhost:10000/health

access_token_header_name: Option<String>

The header name that will be used for the access token. If the header name is empty, the access token will not be forwarded

access_token_header_prefix: Option<String>

Prefix for the access token header. If the prefix is empty, the access token will be forwarded without a prefix

id_token_header_name: Option<String>

The header name that will be used for the id token. If the header name is empty, the id token will not be forwarded

id_token_header_prefix: Option<String>

Prefix for the id token header. If the prefix is empty, the id token will be forwarded without a prefix

cookie_name: String

The cookie name that will be used for the session cookie

logout_path: String

The URL to logout the user

filter_plugin_cookies: bool

Filter out the cookies created and controlled by the plugin If the value is true, the cookies will be filtered out

cookie_duration_in_s: u64

The cookie duration in seconds

token_validation: bool

Option to skip Token Validation

aes_key: Secret<Aes256Gcm>

AES Key

reload_interval_in_h: u64

Reload interval in hours

ticking_interval_in_ms: u64

The interval in milliseconds that the plugin will wait for the discovery endpoint to respond or send a new request.

open_id_configs: Vec<OpenIdConfig>

A list of OpenID Connect configurations that will be used for the filter

Implementations

Source

impl V2PluginConfiguration

pub fn parse(config_bytes: &[u8]) -> Result<(Self, bool)>

fn validate(&self) -> Result<()>

Evaluate the plugin configuration and check if the values are valid. Type checking is done by serde, so we only need to check the values.